about summary refs log tree commit diff
path: root/src/normalise.hh
diff options
context:
space:
mode:
authorEelco Dolstra <e.dolstra@tudelft.nl>2003-10-07T12·27+0000
committerEelco Dolstra <e.dolstra@tudelft.nl>2003-10-07T12·27+0000
commit5d4171f7fb548e06ecd2440f57322b3c77f1074e (patch)
tree06f21a5e6dcf38943f58f7e32f4a23f5bed41da7 /src/normalise.hh
parent563afb7fcc9d6aabec9b867372ea8d651fd12e89 (diff)
* Synchronise terminology with the ICSE paper (e.g., slice -> closure,
  fstate -> Nix expression).
* Fix src/test.cc.

Diffstat (limited to 'src/normalise.hh')
-rw-r--r--src/normalise.hh25
1 files changed, 12 insertions, 13 deletions
diff --git a/src/normalise.hh b/src/normalise.hh
index 59ab325739e4..9b827468195c 100644
--- a/src/normalise.hh
+++ b/src/normalise.hh
@@ -1,30 +1,29 @@
 #ifndef __NORMALISE_H
 #define __NORMALISE_H
 
-#include "fstate.hh"
+#include "expr.hh"
 
 
-/* Normalise an fstate-expression, that is, return an equivalent
-   slice.  (For the meaning of `pending', see expandId()). */
-FSId normaliseFState(FSId id, FSIdSet pending = FSIdSet());
+/* Normalise a Nix expression, that is, return an equivalent
+   closure.  (For the meaning of `pending', see expandId()). */
+FSId normaliseNixExpr(FSId id, FSIdSet pending = FSIdSet());
 
-/* Realise a Slice in the file system. */
-void realiseSlice(const FSId & id, FSIdSet pending = FSIdSet());
+/* Realise a Closure in the file system. */
+void realiseClosure(const FSId & id, FSIdSet pending = FSIdSet());
 
-/* Get the list of root (output) paths of the given
-   fstate-expression. */
-Strings fstatePaths(const FSId & id);
+/* Get the list of root (output) paths of the given Nix expression. */
+Strings nixExprPaths(const FSId & id);
 
 /* Get the list of paths that are required to realise the given
    expression.  For a derive expression, this is the union of
-   requisites of the inputs; for a slice expression, it is the path of
-   each element in the slice.  If `includeExprs' is true, include the
+   requisites of the inputs; for a closure expression, it is the path of
+   each element in the closure.  If `includeExprs' is true, include the
    paths of the Nix expressions themselves.  If `includeSuccessors' is
    true, include the requisites of successors. */
-Strings fstateRequisites(const FSId & id,
+Strings nixExprRequisites(const FSId & id,
     bool includeExprs, bool includeSuccessors);
 
 /* Return the list of the ids of all known fstate-expressions whose
    output ids are completely contained in `ids'. */
 FSIds findGenerators(const FSIds & ids);
@@ -1,30 +1,29 @@
     bool includeExprs, bool includeSuccessors);
 
-/* Return the list of the ids of all known fstate-expressions whose
+/* Return the list of the ids of all known Nix expressions whose
    output ids are completely contained in `ids'. */
 FSIds findGenerators(const FSIds & ids);